==> food-order-tenant-1.0.87.zip: src/function.php <==
<?php
    // this should only be used for testing purposes
    if (defined('TEST_ENV')) {
        //require_once __DIR__ . '/../../orbit-core/src/config.php';
        require_once __DIR__ . '\..\..\core\src\Fcors.php';
        require_once __DIR__ . '\..\..\tests\scripts\bootstrap.php';
        require_once __DIR__ . '\..\..\core\src\generic.php';
        $testInfo['0'] = ("\nFunction Running in Test Environment\n");
    } else {
        // this is code for live environment Dev, Uat, Production
        require_once __DIR__ . "./../error_monitor.php";
        require_once __DIR__ . "./../generic.php";
    }
    
    require_once __DIR__ . "/core.php";
    require_once __DIR__ . "/view.php";
    require_once __DIR__ . "/insert.php";
    require_once __DIR__ . "/update.php";

    $inputData = initializeGeneric();

    $inputData['requiresAdmin'] = 
                [ 
                    'getPreAuthPayments'        =>  [2,4,5,6],                  'acceptedRejectPreAuthPayment' => [2,4,5,6],                  'getOrderList'           => [2,4,5,6], 
                    'viewOrderDetails'          =>  [2,4,5,6],                  'updateStatusOrder'            => [2,4,5,6],                  'updateStatusItem'       => [2,4,5,6],
                    'fullRefund'                =>  [1,2,4,5],                  'partialRefundStaticAmount'    => [1,2,4,5],                  'itemBasedRefund'        => [1,2,4,5],
                    'getFullOrderListPaginated' =>  [2,4,5,6],                  'dashboardData'                => [4,5],                      'insertNewTerms'         => [1,2,3,4],
                    'viewAllTerms'              =>  [1,2,3,4]
                ];
    $inputData['keepLive'] = checkLive();
    if(!isset($inputData['action']) || empty($inputData['action'])){
        $out['status']   = 'failed';
        $out['message']  = 'No Action Found';
        echo json_encode(propagateStatusAndMessage($out));
        exit;
    }
    $action = $inputData['action'];

    // check if action need auth and if does check it valid otherwise move to swithc statments 
    $security = SecurityCheck($inputData); // skip security for a bit 

    if(isset($inputData['tenantId']) == false || $inputData['tenantId'] == null ){
        setTenantId($inputData);
        reinitializeTenantId($inputData);
    }
    if($security['security'] === '1'){
        switch ($action) {
            case "getPreAuthPayments":
                $inputData['nextOperation'] = 'viewPreAuthPayments';
                $out = executeDatabaseOperation($inputData);
                break;
            case "acceptedRejectPreAuthPayment":
                $out = acceptedPreAuthPayment($inputData);
                break;
            case "getOrderList":
                $inputData['nextOperation'] = 'viewAcceptedOrders';
                $out = executeDatabaseOperation($inputData);
                break;
            case "viewOrderDetails":
                $inputData['nextOperation'] = 'viewFullOrderDetails';
                $inputData['viewLevel'] = 'full'; // this can be top or full. the diffrence is that full will return all the order details
                $out = executeDatabaseOperation($inputData);
                break;
            case "updateStatusOrder":
                if (isset($inputData['foodOrder']) && is_array($inputData['foodOrder'])) {
                    if (isset($inputData['foodOrder'][0]) && is_array($inputData['foodOrder'][0])) {
                        $inputData['foodOrder'] = $inputData['foodOrder'][0];
                        $inputData['id'] = $inputData['foodOrder']['id'];
                    }
                }
                if(!isset($inputData['foodOrder']['id']) || $inputData['foodOrder']['id'] == null){
                    $out['status']   = 'failed';
                    $out['message']  = 'Id is required';
                    break;
                }
                if(!isset($inputData['foodOrder']['orderStatus']) || $inputData['foodOrder']['orderStatus'] == null){
                    $out['status']   = 'failed';
                    $out['message']  = 'Order Status is required';
                    break;
                }
                $inputData['recordType'] = 'update';
                $inputData['table'] = 'foodOrder';
                $inputData['dataKey'] = $inputData['table'];
                $out = updateContent($inputData);
                break;
            case "insertNewTerms":
                $inputData['nextOperation'] = 'insertData';
                $inputData['table'] = 'foodOrderTermsOfService';
                $inputData['dataKey'] = $inputData['table'];
                $inputData['recordType'] = 'insert';
                $out = executeDatabaseOperation($inputData);
                break;
            case "viewLatestTerms":
                $inputData['nextOperation'] = 'viewTerms';
                $inputData['recordType'] = 'latest';
                $out = executeDatabaseOperation($inputData);
                break;
            case "viewAllTerms":
                $inputData['nextOperation'] = 'viewTerms';
                $inputData['recordType'] = 'all';
                $out = executeDatabaseOperation($inputData);
                break;
            case "updateStatusItem":
                if (isset($inputData['foodOrderItem']) && is_array($inputData['foodOrderItem'])) {
                    if (isset($inputData['foodOrderItem'][0]) && is_array($inputData['foodOrderItem'][0])) {
                        $inputData['foodOrderItem'] = $inputData['foodOrderItem'][0];
                    }
                }
                if(!isset($inputData['foodOrderItem']['id']) || $inputData['foodOrderItem']['id'] == null){
                    $out['status']   = 'failed';
                    $out['message']  = 'Id is required';
                    break;
                }
                if(!isset($inputData['foodOrderItem']['itemStatus']) || $inputData['foodOrderItem']['itemStatus'] == null){
                    $out['status']   = 'failed';
                    $out['message']  = 'Item Status is required';
                    break;
                }
                $inputData['recordType'] = 'update';
                $inputData['table'] = 'foodOrderItem';
                $inputData['dataKey'] = $inputData['table'];
                $out = updateContent($inputData);
                break;
            case "Receipt":
                $out = setUpReceipt($inputData);
                break;
            case "fullRefund":
                $inputData['refundType'] = 'full';
                $out = processRefund($inputData);
                break;
            case "partialRefundStaticAmount":
                $inputData['refundType'] = 'partial';
                $out = processRefund($inputData);
                break;
            case "itemBasedRefund":
                $inputData['refundType'] = 'itemBased';
                $out = processRefund($inputData);
                break;
            case "getFullOrderListPaginated":
                $inputData['nextOperation'] = 'viewFullOrderListPaginated';
                $out = executeDatabaseOperation($inputData);
                break;
            case "dashboardData":
                $out = dashboardData($inputData);
                break;
            case "test":
                $out['status']   = 'success';
                $out['message']  = 'Test Passed';
                break;       
            default:
                $out['status']   = 'failed';
                $out['message']  = 'No Action Found';
                break;
        }
    }else{
        $out = $security;
        if($security['security'] === '0'){
            unset($out['security']);
        }

    }

    if(defined('TEST_ENV')){
    //    $out['testInfo']['1'] = $testInfo;
    //    $out['testInfo']['2'] = $_GET;
    //    $out['testInfo']['3'] = $_POST;
    //      $out['inputData']     = $inputData;
        $out['security']      = $security;
        $out['action']        = $action;
    }

    echo json_encode(propagateStatusAndMessage($out));
?>

==> food-order-tenant-1.0.88.zip: src/function.php <==
<?php
    // this should only be used for testing purposes
    if (defined('TEST_ENV')) {
        //require_once __DIR__ . '/../../orbit-core/src/config.php';
        require_once __DIR__ . '\..\..\core\src\Fcors.php';
        require_once __DIR__ . '\..\..\tests\scripts\bootstrap.php';
        require_once __DIR__ . '\..\..\core\src\generic.php';
        $testInfo['0'] = ("\nFunction Running in Test Environment\n");
    } else {
        // this is code for live environment Dev, Uat, Production
        require_once __DIR__ . "./../error_monitor.php";
        require_once __DIR__ . "./../generic.php";
    }
    
    require_once __DIR__ . "/core.php";
    require_once __DIR__ . "/view.php";
    require_once __DIR__ . "/insert.php";
    require_once __DIR__ . "/update.php";

    $inputData = initializeGeneric();

    $inputData['requiresAdmin'] = 
                [ 
                    'getPreAuthPayments'        =>  [2,4,5,6],                  'acceptedRejectPreAuthPayment' => [2,4,5,6],                  'getOrderList'           => [2,4,5,6], 
                    'viewOrderDetails'          =>  [2,4,5,6],                  'updateStatusOrder'            => [2,4,5,6],                  'updateStatusItem'       => [2,4,5,6],
                    'fullRefund'                =>  [1,2,4,5],                  'partialRefundStaticAmount'    => [1,2,4,5],                  'itemBasedRefund'        => [1,2,4,5],
                    'getFullOrderListPaginated' =>  [2,4,5,6],                  'dashboardData'                => [4,5],                      'insertNewTerms'         => [1,2,3],
                    'viewAllTerms'              =>  [1,2,3,4],                  'setActiveTerms'               => [1,2,3]
                ];
    $inputData['keepLive'] = checkLive();
    if(!isset($inputData['action']) || empty($inputData['action'])){
        $out['status']   = 'failed';
        $out['message']  = 'No Action Found';
        echo json_encode(propagateStatusAndMessage($out));
        exit;
    }
    $action = $inputData['action'];

    // check if action need auth and if does check it valid otherwise move to swithc statments 
    $security = SecurityCheck($inputData); // skip security for a bit 

    if(isset($inputData['tenantId']) == false || $inputData['tenantId'] == null ){
        setTenantId($inputData);
        reinitializeTenantId($inputData);
    }
    if($security['security'] === '1'){
        switch ($action) {
            case "getPreAuthPayments":
                $inputData['nextOperation'] = 'viewPreAuthPayments';
                $out = executeDatabaseOperation($inputData);
                break;
            case "acceptedRejectPreAuthPayment":
                $out = acceptedPreAuthPayment($inputData);
                break;
            case "getOrderList":
                $inputData['nextOperation'] = 'viewAcceptedOrders';
                $out = executeDatabaseOperation($inputData);
                break;
            case "viewOrderDetails":
                $inputData['nextOperation'] = 'viewFullOrderDetails';
                $inputData['viewLevel'] = 'full'; // this can be top or full. the diffrence is that full will return all the order details
                $out = executeDatabaseOperation($inputData);
                break;
            case "updateStatusOrder":
                if (isset($inputData['foodOrder']) && is_array($inputData['foodOrder'])) {
                    if (isset($inputData['foodOrder'][0]) && is_array($inputData['foodOrder'][0])) {
                        $inputData['foodOrder'] = $inputData['foodOrder'][0];
                        $inputData['id'] = $inputData['foodOrder']['id'];
                    }
                }
                if(!isset($inputData['foodOrder']['id']) || $inputData['foodOrder']['id'] == null){
                    $out['status']   = 'failed';
                    $out['message']  = 'Id is required';
                    break;
                }
                if(!isset($inputData['foodOrder']['orderStatus']) || $inputData['foodOrder']['orderStatus'] == null){
                    $out['status']   = 'failed';
                    $out['message']  = 'Order Status is required';
                    break;
                }
                $inputData['recordType'] = 'update';
                $inputData['table'] = 'foodOrder';
                $inputData['dataKey'] = $inputData['table'];
                $out = updateContent($inputData);
                break;
            case "insertNewTerms":
                $inputData['nextOperation'] = 'insertData';
                $inputData['table'] = 'foodOrderTermsOfService';
                $inputData['dataKey'] = $inputData['table'];
                //$inputData['foodOrderTermsOfService'] = $inputData['foodOrderTermsOfService'][0];
                $inputData['recordType'] = 'insert';
                $out = executeDatabaseOperation($inputData);
                break;
            case "viewLatestTerms":
                $inputData['nextOperation'] = 'viewTerms';
                $inputData['recordType'] = 'latest';
                $out = executeDatabaseOperation($inputData);
                break;
            case "viewAllTerms":
                $inputData['nextOperation'] = 'viewTerms';
                $inputData['recordType'] = 'all';
                $out = executeDatabaseOperation($inputData);
                break;
            case "updateStatusItem":
                if (isset($inputData['foodOrderItem']) && is_array($inputData['foodOrderItem'])) {
                    if (isset($inputData['foodOrderItem'][0]) && is_array($inputData['foodOrderItem'][0])) {
                        $inputData['foodOrderItem'] = $inputData['foodOrderItem'][0];
                    }
                }
                if(!isset($inputData['foodOrderItem']['id']) || $inputData['foodOrderItem']['id'] == null){
                    $out['status']   = 'failed';
                    $out['message']  = 'Id is required';
                    break;
                }
                if(!isset($inputData['foodOrderItem']['itemStatus']) || $inputData['foodOrderItem']['itemStatus'] == null){
                    $out['status']   = 'failed';
                    $out['message']  = 'Item Status is required';
                    break;
                }
                $inputData['recordType'] = 'update';
                $inputData['table'] = 'foodOrderItem';
                $inputData['dataKey'] = $inputData['table'];
                $out = updateContent($inputData);
                break;
            case "Receipt":
                $out = setUpReceipt($inputData);
                break;
            case "fullRefund":
                $inputData['refundType'] = 'full';
                $out = processRefund($inputData);
                break;
            case "partialRefundStaticAmount":
                $inputData['refundType'] = 'partial';
                $out = processRefund($inputData);
                break;
            case "itemBasedRefund":
                $inputData['refundType'] = 'itemBased';
                $out = processRefund($inputData);
                break;
            case "getFullOrderListPaginated":
                $inputData['nextOperation'] = 'viewFullOrderListPaginated';
                $out = executeDatabaseOperation($inputData);
                break;
            case "dashboardData":
                $out = dashboardData($inputData);
                break;
            case "setActiveTerms":
                $inputData['nextOperation'] = 'setActiveTerms';
                $out = executeDatabaseOperation($inputData);
                break;
            case "test":
                $out['status']   = 'success';
                $out['message']  = 'Test Passed';
                break;       
            default:
                $out['status']   = 'failed';
                $out['message']  = 'No Action Found';
                break;
        }
    }else{
        $out = $security;
        if($security['security'] === '0'){
            unset($out['security']);
        }

    }

    if(defined('TEST_ENV')){
    //    $out['testInfo']['1'] = $testInfo;
    //    $out['testInfo']['2'] = $_GET;
    //    $out['testInfo']['3'] = $_POST;
    //      $out['inputData']     = $inputData;
        $out['security']      = $security;
        $out['action']        = $action;
    }

    echo json_encode(propagateStatusAndMessage($out));
?>
